@@ -21,7 +21,8 @@ return 0;
 sub open_last_command
 {
 local ($fh, $user) = @_;
-open($fh, "last $user |");
+local $quser = defined($user) && length($user) ? " ".quotemeta($user) : "";
+open($fh, "last$quser |");
 }
 
 # read_last_line(handle)
@@ -59,5 +60,22 @@ close(WHO);
 return @rv;
 }
 
+# use_md5()
+# Returns 1 if MD5 encryption should be used, 2 if blowfish
+sub use_md5
+{
+local $lref = &read_file_lines("/etc/security/policy.conf");
+local $l;
+foreach $l (@$lref) {
+	if ($l =~ /^CRYPT_DEFAULT\s*=\s*"([^"]*)"/ ||
+	    $l =~ /^CRYPT_DEFAULT\s*=\s*'([^']*)'/ ||
+	    $l =~ /^CRYPT_DEFAULT\s*=\s*(\S+)/) {
+		return 1 if ($1 eq "1");
+		return 2 if ($1 eq "2a");
+		}
+	}
+return 0;
+}
+
 1;
 
